@@ -9,14 +9,12 @@ use strict;
 use warnings;
 use base qw( Net::Prometheus::Metric );
 
-our $VERSION = '0.07_001';
+our $VERSION = '0.01';
 
 use Carp;
 
 use constant _type => "counter";
 
-__PACKAGE__->MAKE_child_class;
-
 =head1 NAME
 
 C<Net::Prometheus::Counter> - a monotonically-increasing counter metric
@@ -41,7 +39,7 @@ C<Net::Prometheus::Counter> - a monotonically-increasing counter metric
 =head1 DESCRIPTION
 
 This class provides a counter metric - a value that monotonically increases,
-usually used to represent occurrences of some event that happens within the
+usually used to represent occurrances of some event that happens within the
 instrumented program. It is a subclass of L<Net::Prometheus::Metric>.
 
 =cut
@@ -58,6 +56,8 @@ L<Net::Prometheus::Metric>.
 
 =cut
 
+__PACKAGE__->make_childlabel_method( $_ ) for qw( inc );
+
 sub new
 {
    my $class = shift;
@@ -66,8 +66,6 @@ sub new
 
    $self->{values} = {};
 
-   $self->inc( 0 ) if !$self->labelcount;
-
    return $self;
 }
 
@@ -77,8 +75,7 @@ sub new
 
 =head2 inc
 
-   $counter->inc( @label_values, $delta )
-   $counter->inc( \%labels, $delta )
+   $counter->inc( [ @label_values ], $delta )
 
    $child->inc( $delta )
 
@@ -87,27 +84,26 @@ supplied and must be non-negative.
 
 =cut
 
-__PACKAGE__->MAKE_child_method( 'inc' );
 sub _inc_child
 {
    my $self = shift;
    my ( $labelkey, $delta ) = @_;
-   defined $delta or $delta = 1;
+   $delta //= 1;
    $delta >= 0 or
       croak "Cannot increment a counter by a negative value";
 
    $self->{values}{$labelkey} += $delta;
 }
 
-sub samples
+sub render
 {
    my $self = shift;
 
    my $values = $self->{values};
+   my $fullname = $self->fullname;
 
-   return map {
-      $self->make_sample( undef, $_, $values->{$_} )
-   } sort keys %$values;
+   return $self->SUPER::render,
+      map { $self->_render_value( $fullname, $_, $values->{$_} ) } sort keys %$values;
 }
 
 =head1 AUTHOR
