@@ -9,15 +9,10 @@ use strict;
 use warnings;
 use base qw( Net::Prometheus::Metric );
 
-our $VERSION = '0.07_001';
-
-use Carp;
-use List::Util 1.33 qw( any );
+our $VERSION = '0.01';
 
 use constant _type => "summary";
 
-__PACKAGE__->MAKE_child_class;
-
 =head1 NAME
 
 C<Net::Prometheus::Summary> - summarise individual numeric observations
@@ -63,30 +58,23 @@ L<Net::Prometheus::Metric>.
 
 =cut
 
+__PACKAGE__->make_childlabel_method( $_ ) for qw( observe );
+
 sub new
 {
    my $class = shift;
-   my %opts = @_;
-
-   $opts{labels} and any { $_ eq "quantile" } @{ $opts{labels} } and
-      croak "A Summary may not have a label called 'quantile'";
 
    my $self = $class->SUPER::new( @_ );
 
    $self->{counts} = {};
    $self->{sums}   = {};
 
-   if( !$self->labelcount ) {
-      $self->{counts}{""} = $self->{sums}{""} = 0;
-   }
-
    return $self;
 }
 
 =head2 observe
 
-   $summary->observe( @label_values, $value )
-   $summary->observe( \%labels, $value )
+   $summary->observe( [ @label_values ], $value )
 
    $child->observe( $value )
 
@@ -94,7 +82,6 @@ Increment the summary sum by the given value, and the count by 1.
 
 =cut
 
-__PACKAGE__->MAKE_child_method( 'observe' );
 sub _observe_child
 {
    my $self = shift;
@@ -104,17 +91,17 @@ sub _observe_child
    $self->{sums}  {$labelkey} += $value;
 }
 
-sub samples
+sub render
 {
    my $self = shift;
 
    my $counts = $self->{counts};
    my $sums   = $self->{sums};
+   my $fullname = $self->fullname;
 
-   return map {
-      $self->make_sample( count => $_, $counts->{$_} ),
-      $self->make_sample( sum   => $_, $sums->{$_} )
-   } sort keys %$counts;
+   return $self->SUPER::render,
+      map { $self->_render_value( "${fullname}_count", $_, $counts->{$_} ),
+            $self->_render_value( "${fullname}_sum",   $_, $sums->{$_} ) } sort keys %$counts;
 }
 
 =head1 AUTHOR
